CheckBoxNG
==========

:term:`CheckBoxNG` is a hardware testing tool useful for certifying laptops,
desktops and servers with Ubuntu. It is a new version of :term:`CheckBox` that
is built directly on top of :term:`PlainBox`

CheckBoxNG *replaces* CheckBox, where applicable. 


Installation
============

Installation is a bit tricky. You need to have python3-plainbox installed first
(which may come from the checkbox daily ppa) or you need to (recommended, for
the time being) develop plainbox.
